# wscodec
Websensor Encoder and Decoder -- in development, not recommended for production use yet.


`pip install wscodec`

Find documentation at https://wscodec.readthedocs.io/. This is very much a work in progress. 
A lot of it was written a while ago and is now out of date.
